@@ -1,6 +1,6 @@
 /* graphene-matrix.h: 4x4 matrix
  *
- * Copyright © 2014  Emmanuele Bassi
+ * Copyright 2014  Emmanuele Bassi
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -1058,11 +1058,10 @@ graphene_matrix_transform_box (const graphene_matrix_t *m,
                                graphene_box_t          *res)
 {
   graphene_vec3_t points[8];
-  unsigned int i;
 
   graphene_box_get_vertices (b, points);
 
-  for (i = 0; i < 8; i++)
+  for (int i = 0; i < 8; i++)
     graphene_simd4x4f_point3_mul (&m->value, &(points[i].value), &(points[i].value));
 
   graphene_box_init_from_vectors (res, 8, points);
@@ -1151,9 +1150,6 @@ graphene_matrix_project_rect_bounds (const graphene_matrix_t *m,
 {
   graphene_point_t points[4];
   graphene_point_t ret[4];
-  float min_x, min_y;
-  float max_x, max_y;
-  int i;
 
   graphene_rect_get_top_left (r, &points[0]);
   graphene_rect_get_top_right (r, &points[1]);
@@ -1165,17 +1161,13 @@ graphene_matrix_project_rect_bounds (const graphene_matrix_t *m,
   graphene_matrix_project_point (m, &points[2], &ret[2]);
   graphene_matrix_project_point (m, &points[3], &ret[3]);
 
-  min_x = max_x = ret[0].x;
-  min_y = max_y = ret[0].y;
+  graphene_simd4f_t v_x = graphene_simd4f_init (ret[0].x, ret[1].x, ret[2].x, ret[3].x);
+  graphene_simd4f_t v_y = graphene_simd4f_init (ret[0].y, ret[1].y, ret[2].y, ret[3].y);
 
-  for (i = 1; i < 4; i++)
-    {
-      min_x = MIN (ret[i].x, min_x);
-      min_y = MIN (ret[i].y, min_y);
-
-      max_x = MAX (ret[i].x, max_x);
-      max_y = MAX (ret[i].y, max_y);
-    }
+  float min_x = graphene_simd4f_get_x (graphene_simd4f_min_val (v_x));
+  float max_x = graphene_simd4f_get_x (graphene_simd4f_max_val (v_x));
+  float min_y = graphene_simd4f_get_x (graphene_simd4f_min_val (v_y));
+  float max_y = graphene_simd4f_get_x (graphene_simd4f_max_val (v_y));
 
   graphene_rect_init (res, min_x, min_y, max_x - min_x, max_y - min_y);
 }
@@ -1660,14 +1652,12 @@ void
 graphene_matrix_normalize (const graphene_matrix_t *m,
                            graphene_matrix_t       *res)
 {
-  graphene_simd4f_t n;
-  float ww;
 
-  ww = graphene_simd4f_get_w (m->value.w);
-  if (ww == 0.f)
+  float ww = graphene_simd4f_get_w (m->value.w);
+  if (graphene_approx_val (ww, 0.f))
     return;
 
-  n = graphene_simd4f_splat (1.f / ww);
+  graphene_simd4f_t n = graphene_simd4f_splat (1.f / ww);
 
   res->value.x = graphene_simd4f_mul (m->value.x, n);
   res->value.y = graphene_simd4f_mul (m->value.y, n);
@@ -1787,13 +1777,13 @@ matrix_decompose_2d (const graphene_matrix_t *m,
         scale_r->y = -scale_r->y;
     }
 
-  if (scale_r->x != 0.f)
+  if (!graphene_approx_val (scale_r->x, 0.f))
     {
       row0x = row0x * (1.f / scale_r->x);
       row0y = row0y * (1.f / scale_r->y);
     }
 
-  if (scale_r->y != 0.f)
+  if (!graphene_approx_val (scale_r->y, 0.f))
     {
       row1x = row1x * (1.f / scale_r->x);
       row1y = row1y * (1.f / scale_r->y);
@@ -1837,7 +1827,7 @@ matrix_decompose_3d (const graphene_matrix_t *m,
   graphene_simd4f_t perspective_v;
   graphene_simd4f_t cross;
 
-  if (graphene_matrix_get_value (m, 3, 3) == 0.f)
+  if (graphene_approx_val (graphene_simd4f_get_w (m->value.w), 0.f))
     return false;
 
   local = *m;
@@ -1852,7 +1842,7 @@ matrix_decompose_3d (const graphene_matrix_t *m,
   perspective = local;
   perspective.value.w = graphene_simd4f_init (0.f, 0.f, 0.f, 1.f);
 
-  if (graphene_matrix_determinant (&perspective) == 0.f)
+  if (graphene_approx_val (graphene_matrix_determinant (&perspective), 0.f))
     return false;
 
   perspective_v = graphene_simd4f_init (graphene_simd4f_get_w (local.value.x),
@@ -2099,20 +2089,22 @@ graphene_matrix_interpolate (const graphene_matrix_t *a,
 
       /* Skew */
       shear = graphene_lerp (shear_a[YZ_SHEAR], shear_b[YZ_SHEAR], factor);
-      if (shear != 0.f)
+      if (!graphene_approx_val (shear, 0.f))
         graphene_matrix_skew_yz (res, shear);
 
       shear = graphene_lerp (shear_a[XZ_SHEAR], shear_b[XZ_SHEAR], factor);
-      if (shear != 0.f)
+      if (!graphene_approx_val (shear, 0.f))
         graphene_matrix_skew_xz (res, shear);
 
       shear = graphene_lerp (shear_a[XY_SHEAR], shear_b[XY_SHEAR], factor);
-      if (shear != 0.f)
+      if (!graphene_approx_val (shear, 0.f))
         graphene_matrix_skew_xy (res, shear);
 
       /* Scale */
       graphene_point3d_interpolate (&scale_a, &scale_b, factor, &scale_r);
-      if (scale_r.x != 1.f && scale_r.y != 1.f && scale_r.z != 1.f)
+      if (!graphene_approx_val (scale_r.x, 1.f) ||
+          !graphene_approx_val (scale_r.y, 1.f) ||
+          !graphene_approx_val (scale_r.z, 1.f))
         graphene_matrix_scale (res, scale_r.x, scale_r.y, scale_r.z);
     }
 }
@@ -2136,9 +2128,7 @@ graphene_matrix_interpolate (const graphene_matrix_t *a,
 void
 graphene_matrix_print (const graphene_matrix_t *m)
 {
-  int i;
-
-  for (i = 0; i < 4; i++)
+  for (int i = 0; i < 4; i++)
     {
       fprintf (stderr,
                "| %+.6f %+.6f %+.6f %+.6f |\n",
