@@ -1,6 +1,6 @@
 /* graphene-rect.c: Rectangular type
  *
- * Copyright © 2014  Emmanuele Bassi
+ * Copyright 2014  Emmanuele Bassi
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -171,16 +171,14 @@ bool
 graphene_rect_equal (const graphene_rect_t *a,
                      const graphene_rect_t *b)
 {
-  graphene_rect_t r_a, r_b;
-
   if (a == b)
     return true;
 
   if (a == NULL || b == NULL)
     return false;
 
-  r_a = *a;
-  r_b = *b;
+  graphene_rect_t r_a = *a;
+  graphene_rect_t r_b = *b;
 
   graphene_rect_normalize_in_place (&r_a);
   graphene_rect_normalize_in_place (&r_b);
@@ -503,7 +501,7 @@ graphene_rect_intersection (const graphene_rect_t *a,
   x_1 = MAX (ra.origin.x, rb.origin.x);
   y_1 = MAX (ra.origin.y, rb.origin.y);
   x_2 = MIN (ra.origin.x + ra.size.width, rb.origin.x + rb.size.width);
-  y_2 = MIN (ra.origin.y + ra.size.height, rb.origin.x + rb.size.height);
+  y_2 = MIN (ra.origin.y + ra.size.height, rb.origin.y + rb.size.height);
 
   if (x_1 >= x_2 || y_1 >= y_2)
     {
@@ -811,11 +809,7 @@ graphene_rect_interpolate (const graphene_rect_t *a,
   res->size.height = graphene_lerp (ra.size.height, rb.size.height, factor);
 }
 
-#ifdef _MSC_VER
-static const graphene_rect_t _graphene_rect_zero = { {0.f, 0.f}, {0.f, 0.f} };
-#else
-static const graphene_rect_t _graphene_rect_zero = GRAPHENE_RECT_INIT (0, 0, 0, 0);
-#endif
+static const graphene_rect_t _graphene_rect_zero;
 
 /**
  * graphene_rect_zero:
